@@ -73,7 +73,7 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
 
     connect(mUi->mInlineCheck, &QCheckBox::stateChanged, this, &AttachmentEditDialog::inlineChanged);
     connect(mUi->mURLRequester,
-            qOverload<const QUrl &>(&KUrlRequester::urlSelected),
+            &KUrlRequester::urlSelected,
             this,
             static_cast<void (AttachmentEditDialog::*)(const QUrl &)>(&AttachmentEditDialog::urlChanged));
     connect(mUi->mURLRequester,
