@@ -1,25 +1,11 @@
 /*
- *  Copyright (C) 2014 Sandro Knauß <knauss@kolabsys.com>
+ *  SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "attendeetablemodel.h"
 
-#include <KCalendarCore/Attendee>
 #include <KEmailAddress>
 
 #include <KLocalizedString>
@@ -28,8 +14,6 @@ using namespace IncidenceEditorNG;
 
 AttendeeTableModel::AttendeeTableModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , mKeepEmpty(false)
-    , mRemoveEmptyLines(false)
 {
 }
 
@@ -48,7 +32,7 @@ Qt::ItemFlags AttendeeTableModel::flags(const QModelIndex &index) const
     if (!index.isValid()) {
         return Qt::ItemIsEnabled;
     }
-    if (index.column() == Available || index.column() == Name || index.column() == Email) { //Available is read only
+    if (index.column() == Available || index.column() == Name || index.column() == Email) { // Available is read only
         return QAbstractTableModel::flags(index);
     } else {
         return QAbstractTableModel::flags(index) | Qt::ItemIsEditable;
@@ -58,11 +42,11 @@ Qt::ItemFlags AttendeeTableModel::flags(const QModelIndex &index) const
 QVariant AttendeeTableModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
 
     if (index.row() >= mAttendeeList.size()) {
-        return QVariant();
+        return {};
     }
 
     const KCalendarCore::Attendee attendee = mAttendeeList[index.row()];
@@ -72,8 +56,7 @@ QVariant AttendeeTableModel::data(const QModelIndex &index, int role) const
             return attendee.role();
         case FullName:
             return attendee.fullName();
-        case Available:
-        {
+        case Available: {
             AvailableStatus available = mAttendeeAvailable[index.row()];
             if (role == Qt::DisplayRole) {
                 switch (available) {
@@ -107,14 +90,15 @@ QVariant AttendeeTableModel::data(const QModelIndex &index, int role) const
     if (role == AttendeeRole) {
         return QVariant::fromValue(attendee);
     }
-    return QVariant();
+    return {};
 }
 
 bool AttendeeTableModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    QString email, name;
+    QString email;
+    QString name;
     if (index.isValid() && role == Qt::EditRole) {
-        KCalendarCore::Attendee &attendee = mAttendeeList[index.row()];
+        KCalendarCore::Attendee &attendee = mAttendeeList[index.row()]; // clazy:exclude=detaching-member
         switch (index.column()) {
         case Role:
             attendee.setRole(static_cast<KCalendarCore::Attendee::Role>(value.toInt()));
@@ -158,7 +142,7 @@ bool AttendeeTableModel::setData(const QModelIndex &index, const QVariant &value
 QVariant AttendeeTableModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (role != Qt::DisplayRole) {
-        return QVariant();
+        return {};
     }
 
     if (orientation == Qt::Horizontal) {
@@ -170,8 +154,7 @@ QVariant AttendeeTableModel::headerData(int section, Qt::Orientation orientation
         case Available:
             return i18nc("Is attendee available for incidence", "Available");
         case Status:
-            return i18nc("Status of attendee in an incidence (accepted, declined, delegated, ...)",
-                         "Status");
+            return i18nc("Status of attendee in an incidence (accepted, declined, delegated, ...)", "Status");
         case CuType:
             return i18nc("Type of calendar user (vCard attribute)", "User Type");
         case Response:
@@ -183,7 +166,7 @@ QVariant AttendeeTableModel::headerData(int section, Qt::Orientation orientation
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 bool AttendeeTableModel::insertRows(int position, int rows, const QModelIndex &parent)
@@ -227,7 +210,7 @@ bool AttendeeTableModel::insertAttendee(int position, const KCalendarCore::Atten
 
 void AttendeeTableModel::setAttendees(const KCalendarCore::Attendee::List &attendees)
 {
-    Q_EMIT layoutAboutToBeChanged();
+    beginResetModel();
 
     mAttendeeList = attendees;
     mAttendeeAvailable.clear();
@@ -235,7 +218,7 @@ void AttendeeTableModel::setAttendees(const KCalendarCore::Attendee::List &atten
 
     addEmptyAttendee();
 
-    Q_EMIT layoutChanged();
+    endResetModel();
 }
 
 KCalendarCore::Attendee::List AttendeeTableModel::attendees() const
@@ -247,7 +230,7 @@ void AttendeeTableModel::addEmptyAttendee()
 {
     if (mKeepEmpty) {
         bool create = true;
-        for (const KCalendarCore::Attendee &attendee : qAsConst(mAttendeeList)) {
+        for (const KCalendarCore::Attendee &attendee : std::as_const(mAttendeeList)) {
             if (attendee.fullName().isEmpty()) {
                 create = false;
                 break;
@@ -290,10 +273,8 @@ ResourceFilterProxyModel::ResourceFilterProxyModel(QObject *parent)
 
 bool ResourceFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
-    QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType,
-                                                   sourceParent);
-    KCalendarCore::Attendee::CuType cuType
-        = static_cast<KCalendarCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
+    const QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType, sourceParent);
+    KCalendarCore::Attendee::CuType cuType = static_cast<KCalendarCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
 
     return cuType == KCalendarCore::Attendee::Resource || cuType == KCalendarCore::Attendee::Room;
 }
@@ -305,10 +286,8 @@ AttendeeFilterProxyModel::AttendeeFilterProxyModel(QObject *parent)
 
 bool AttendeeFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
-    QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType,
-                                                   sourceParent);
-    KCalendarCore::Attendee::CuType cuType
-        = static_cast<KCalendarCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
+    const QModelIndex cuTypeIndex = sourceModel()->index(sourceRow, AttendeeTableModel::CuType, sourceParent);
+    KCalendarCore::Attendee::CuType cuType = static_cast<KCalendarCore::Attendee::CuType>(sourceModel()->data(cuTypeIndex).toUInt());
 
     return !(cuType == KCalendarCore::Attendee::Resource || cuType == KCalendarCore::Attendee::Room);
 }
