@@ -22,10 +22,10 @@
 #include "ui_dialogdesktop.h"
 #include <CalendarSupport/FreeBusyItemModel>
 
-#include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
-#include <Akonadi/Contact/ContactGroupExpandJob>
-#include <Akonadi/Contact/ContactGroupSearchJob>
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
+#include <Akonadi/AbstractEmailAddressSelectionDialog>
+#include <Akonadi/ContactGroupExpandJob>
+#include <Akonadi/ContactGroupSearchJob>
+#include <Akonadi/EmailAddressSelectionDialog>
 
 #include <KCalUtils/Stringify>
 #include <KEmailAddress>
@@ -36,7 +36,6 @@
 #include <KMessageBox>
 #include <QPointer>
 #include <QTreeView>
-#include <kcontacts_version.h>
 
 using namespace IncidenceEditorNG;
 
@@ -124,12 +123,14 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
 
     // conflict resolver (should show also resources)
     connect(mDataModel, &AttendeeTableModel::layoutChanged, this, &IncidenceAttendee::slotConflictResolverLayoutChanged);
+    connect(mDataModel, &AttendeeTableModel::modelReset, this, &IncidenceAttendee::slotConflictResolverLayoutChanged);
     connect(mDataModel, &AttendeeTableModel::rowsAboutToBeRemoved, this, &IncidenceAttendee::slotConflictResolverAttendeeRemoved);
     connect(mDataModel, &AttendeeTableModel::rowsInserted, this, &IncidenceAttendee::slotConflictResolverAttendeeAdded);
     connect(mDataModel, &AttendeeTableModel::dataChanged, this, &IncidenceAttendee::slotConflictResolverAttendeeChanged);
 
     // Group substitution
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::slotGroupSubstitutionLayoutChanged);
+    connect(filterProxyModel, &AttendeeFilterProxyModel::modelReset, this, &IncidenceAttendee::slotGroupSubstitutionLayoutChanged);
     connect(filterProxyModel, &AttendeeFilterProxyModel::rowsAboutToBeRemoved, this, &IncidenceAttendee::slotGroupSubstitutionAttendeeRemoved);
     connect(filterProxyModel, &AttendeeFilterProxyModel::rowsInserted, this, &IncidenceAttendee::slotGroupSubstitutionAttendeeAdded);
     connect(filterProxyModel, &AttendeeFilterProxyModel::dataChanged, this, &IncidenceAttendee::slotGroupSubstitutionAttendeeChanged);
@@ -140,11 +141,11 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(filterProxyModel, &AttendeeFilterProxyModel::dataChanged, this, &IncidenceAttendee::updateCount);
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::updateCount);
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::filterLayoutChanged);
+    connect(filterProxyModel, &AttendeeFilterProxyModel::modelReset, this, &IncidenceAttendee::updateCount);
+    connect(filterProxyModel, &AttendeeFilterProxyModel::modelReset, this, &IncidenceAttendee::filterLayoutChanged);
 }
 
-IncidenceAttendee::~IncidenceAttendee()
-{
-}
+IncidenceAttendee::~IncidenceAttendee() = default;
 
 void IncidenceAttendee::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
@@ -202,15 +203,15 @@ void IncidenceAttendee::save(const KCalendarCore::Incidence::Ptr &incidence)
             continue;
         }
         if (KEmailAddress::isValidAddress(attendee.email())) {
-            if (KMessageBox::warningYesNo(nullptr,
-                                          i18nc("@info",
-                                                "%1 does not look like a valid email address. "
-                                                "Are you sure you want to invite this participant?",
-                                                attendee.email()),
-                                          i18nc("@title:window", "Invalid Email Address"),
-                                          KGuiItem(i18nc("@action:button", "Invite"), QStringLiteral("dialog-ok")),
-                                          KGuiItem(i18nc("@action:button", "Do Not Invite"), QStringLiteral("dialog-cancel")))
-                != KMessageBox::Yes) {
+            if (KMessageBox::warningTwoActions(nullptr,
+                                               i18nc("@info",
+                                                     "%1 does not look like a valid email address. "
+                                                     "Are you sure you want to invite this participant?",
+                                                     attendee.email()),
+                                               i18nc("@title:window", "Invalid Email Address"),
+                                               KGuiItem(i18nc("@action:button", "Invite"), QStringLiteral("dialog-ok")),
+                                               KGuiItem(i18nc("@action:button", "Do Not Invite"), QStringLiteral("dialog-cancel")))
+                != KMessageBox::ButtonCode::PrimaryAction) {
                 skip = true;
             }
         }
@@ -421,7 +422,8 @@ void IncidenceAttendee::insertAddresses(const KContacts::Addressee::List &list)
 void IncidenceAttendee::slotSelectAddresses()
 {
     QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
-    const KPluginMetaData editWidgetPlugin(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR))
+                                           + QStringLiteral("/akonadi/emailaddressselectionldapdialogplugin"));
 
     const auto result = KPluginFactory::instantiatePlugin<Akonadi::AbstractEmailAddressSelectionDialog>(editWidgetPlugin, mParentWidget);
     if (result) {
@@ -443,7 +445,10 @@ void IncidenceAttendee::slotSelectAddresses()
                 bool rsvp = true;
 
                 int pos = 0;
-                KCalendarCore::Attendee newAt(selection.name(), selection.email(), rsvp, partStat, KCalendarCore::Attendee::ReqParticipant);
+                QString name;
+                QString email;
+                KEmailAddress::extractEmailAddressAndName(selection.email(), email, name);
+                KCalendarCore::Attendee newAt(selection.name(), email, rsvp, partStat, KCalendarCore::Attendee::ReqParticipant);
                 dataModel()->insertAttendee(pos, newAt);
 
                 mExpandGroupJobs.insert(job, newAt.uid());
@@ -451,11 +456,7 @@ void IncidenceAttendee::slotSelectAddresses()
             } else {
                 KContacts::Addressee contact;
                 contact.setName(selection.name());
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-                contact.insertEmail(selection.email());
-#else
                 contact.addEmail(KContacts::Email(selection.email()));
-#endif
 
                 if (selection.item().hasPayload<KContacts::Addressee>()) {
                     contact.setUid(selection.item().payload<KContacts::Addressee>().uid());
@@ -726,7 +727,11 @@ void IncidenceAttendee::insertAttendeeFromAddressee(const KContacts::Addressee &
         partStat = KCalendarCore::Attendee::Accepted;
         rsvp = false;
     }
-    KCalendarCore::Attendee newAt(a.realName(), a.preferredEmail(), rsvp, partStat, KCalendarCore::Attendee::ReqParticipant, a.uid());
+    QString name;
+    QString email;
+    KEmailAddress::extractEmailAddressAndName(a.preferredEmail(), email, name);
+
+    KCalendarCore::Attendee newAt(a.realName(), email, rsvp, partStat, KCalendarCore::Attendee::ReqParticipant, a.uid());
     if (pos < 0) {
         pos = dataModel()->rowCount() - 1;
     }
@@ -778,21 +783,21 @@ void IncidenceAttendee::slotOrganizerChanged(const QString &newOrganizer)
         }
     }
 
-    int answer = KMessageBox::No;
+    int answer;
     if (currentOrganizerAttendee > -1) {
-        answer = KMessageBox::questionYesNo(mParentWidget,
-                                            i18nc("@option",
-                                                  "You are changing the organizer of this event. "
-                                                  "Since the organizer is also attending this event, would you "
-                                                  "like to change the corresponding attendee as well?"),
-                                            QString(),
-                                            KGuiItem(i18nc("@action:button", "Change Attendee"), QStringLiteral("dialog-ok")),
-                                            KGuiItem(i18nc("@action:button", "Do Not Change"), QStringLiteral("dialog-cancel")));
+        answer = KMessageBox::questionTwoActions(mParentWidget,
+                                                 i18nc("@option",
+                                                       "You are changing the organizer of this event. "
+                                                       "Since the organizer is also attending this event, would you "
+                                                       "like to change the corresponding attendee as well?"),
+                                                 QString(),
+                                                 KGuiItem(i18nc("@action:button", "Change Attendee"), QStringLiteral("dialog-ok")),
+                                                 KGuiItem(i18nc("@action:button", "Do Not Change"), QStringLiteral("dialog-cancel")));
     } else {
-        answer = KMessageBox::Yes;
+        answer = KMessageBox::ButtonCode::PrimaryAction;
     }
 
-    if (answer == KMessageBox::Yes) {
+    if (answer == KMessageBox::ButtonCode::PrimaryAction) {
         if (currentOrganizerAttendee > -1) {
             mDataModel->removeRows(currentOrganizerAttendee, 1);
         }
