@@ -12,7 +12,7 @@
 #include "incidenceeditor_debug.h"
 
 #include <CalendarSupport/KCalPrefs>
-#include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
+#include <akonadi/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
 
 #include <KContacts/Addressee>
 
@@ -24,7 +24,6 @@
 #include <KEmailAddress>
 
 #include <KIO/Job>
-#include <KIO/StoredTransferJob>
 #include <KLocalizedString>
 
 #include <QFile>
@@ -53,7 +52,7 @@ public:
 
     /// Methods
     Q_REQUIRED_RESULT KCalendarCore::Person organizerAsPerson() const;
-    KCalendarCore::Attendee organizerAsAttendee(const KCalendarCore::Person &organizer) const;
+    Q_REQUIRED_RESULT KCalendarCore::Attendee organizerAsAttendee(const KCalendarCore::Person &organizer) const;
 
     void todoDefaults(const KCalendarCore::Todo::Ptr &todo) const;
     void eventDefaults(const KCalendarCore::Event::Ptr &event) const;
@@ -135,10 +134,20 @@ void IncidenceDefaultsPrivate::eventDefaults(const KCalendarCore::Event::Ptr &ev
         }
     }
 
+    if (startDT.timeSpec() == Qt::LocalTime) {
+        // Ensure the default is not "floating"
+        startDT.setTimeZone(QTimeZone::systemTimeZone());
+    }
+
     const QTime defaultDurationTime = KCalPrefs::instance()->defaultDuration().time();
     const int defaultDuration = (defaultDurationTime.hour() * 3600) + (defaultDurationTime.minute() * 60);
 
-    const QDateTime endDT = mEndDt.isValid() ? mEndDt : startDT.addSecs(defaultDuration);
+    QDateTime endDT = mEndDt.isValid() ? mEndDt : startDT.addSecs(defaultDuration);
+
+    if (endDT.timeSpec() == Qt::LocalTime) {
+        // Ensure the default is not "floating"
+        endDT.setTimeZone(QTimeZone::systemTimeZone());
+    }
 
     event->setDtStart(startDT);
     event->setDtEnd(endDT);
@@ -151,7 +160,11 @@ void IncidenceDefaultsPrivate::eventDefaults(const KCalendarCore::Event::Ptr &ev
 
 void IncidenceDefaultsPrivate::journalDefaults(const KCalendarCore::Journal::Ptr &journal) const
 {
-    const QDateTime startDT = mStartDt.isValid() ? mStartDt : QDateTime::currentDateTime();
+    QDateTime startDT = mStartDt.isValid() ? mStartDt : QDateTime::currentDateTime();
+    if (startDT.timeSpec() == Qt::LocalTime) {
+        // Ensure the default is not "floating"
+        startDT.setTimeZone(QTimeZone::systemTimeZone());
+    }
     journal->setDtStart(startDT);
     journal->setAllDay(true);
 }
@@ -163,26 +176,39 @@ void IncidenceDefaultsPrivate::todoDefaults(const KCalendarCore::Todo::Ptr &todo
         todo->setCategories(relatedTodo->categories());
     }
 
+    // Now, but not in the "floating" time zone.
+    auto const systemNow = QDateTime::currentDateTime().toTimeZone(QTimeZone::systemTimeZone());
+
     if (mEndDt.isValid()) {
-        todo->setDtDue(mEndDt, true /** first */);
+        if (mEndDt.timeSpec() == Qt::LocalTime) {
+            // Ensure the default is not "floating"
+            todo->setDtDue(mEndDt.toTimeZone(QTimeZone::systemTimeZone()), true);
+        } else {
+            todo->setDtDue(mEndDt, true /* first */);
+        }
     } else if (relatedTodo && relatedTodo->hasDueDate()) {
         todo->setDtDue(relatedTodo->dtDue(true), true /** first */);
         todo->setAllDay(relatedTodo->allDay());
     } else if (relatedTodo) {
         todo->setDtDue(QDateTime());
     } else {
-        todo->setDtDue(QDateTime::currentDateTime().addDays(1), true /** first */);
+        todo->setDtDue(systemNow.addDays(1), true /** first */);
     }
 
     if (mStartDt.isValid()) {
-        todo->setDtStart(mStartDt);
+        if (mStartDt.timeSpec() == Qt::LocalTime) {
+            // Ensure the default is not "floating"
+            todo->setDtStart(mStartDt.toTimeZone(QTimeZone::systemTimeZone()));
+        } else {
+            todo->setDtStart(mStartDt);
+        }
     } else if (relatedTodo && !relatedTodo->hasStartDate()) {
         todo->setDtStart(QDateTime());
     } else if (relatedTodo && relatedTodo->hasStartDate() && relatedTodo->dtStart() <= todo->dtDue()) {
         todo->setDtStart(relatedTodo->dtStart());
         todo->setAllDay(relatedTodo->allDay());
-    } else if (!mEndDt.isValid() || (QDateTime::currentDateTime() < mEndDt)) {
-        todo->setDtStart(QDateTime::currentDateTime());
+    } else if (!mEndDt.isValid() || systemNow < mEndDt) {
+        todo->setDtStart(systemNow);
     } else {
         todo->setDtStart(mEndDt.addDays(-1));
     }
