@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef RESOURCEITEM_H
-#define RESOURCEITEM_H
+#pragma once
 
 #include <KLDAP/LdapClient>
 
@@ -30,7 +29,7 @@ public:
     /**
       A shared pointer to an ResourceItem object.
     */
-    typedef QSharedPointer<ResourceItem> Ptr;
+    using Ptr = QSharedPointer<ResourceItem>;
 
     ResourceItem(const KLDAP::LdapDN &dn, const QStringList &attrs, const KLDAP::LdapClient &ldapClient, const ResourceItem::Ptr &parent = ResourceItem::Ptr());
     ~ResourceItem() override;
@@ -114,4 +113,3 @@ private:
 Q_DECLARE_TYPEINFO(IncidenceEditorNG::ResourceItem::Ptr, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(IncidenceEditorNG::ResourceItem::Ptr)
 //@endcond
-#endif // RESOURCEITEM_H
