@@ -10,81 +10,79 @@
 #include "ui_resourcemanagement.h"
 #include <CalendarSupport/FreeBusyItem>
 
-#include "freebusyganttproxymodel.h"
-
-#include <Akonadi/Calendar/FreeBusyManager>
+#include <Akonadi/FreeBusyManager>
 
 #include <EventViews/AgendaView>
 
 #include <KCalendarCore/Event>
-#include <KCalendarCore/MemoryCalendar>
-
-#include <KGantt/KGanttGraphicsView>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
+#include <KWindowConfig>
 #include <QColor>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QStringList>
+#include <QWindow>
 
 using namespace IncidenceEditorNG;
-
+namespace
+{
+static const char myResourceManagementConfigGroupName[] = "ResourceManagement";
+}
 class FreebusyViewCalendar : public EventViews::ViewCalendar
 {
 public:
-    ~FreebusyViewCalendar() override
-    {
-    }
+    ~FreebusyViewCalendar() override = default;
 
-    bool isValid(const KCalendarCore::Incidence::Ptr &incidence) const override
+    Q_REQUIRED_RESULT bool isValid(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         return isValid(incidence->uid());
     }
 
-    bool isValid(const QString &incidenceIdentifier) const override
+    Q_REQUIRED_RESULT bool isValid(const QString &incidenceIdentifier) const override
     {
         return incidenceIdentifier.startsWith(QLatin1String("fb-"));
     }
 
-    QString displayName(const KCalendarCore::Incidence::Ptr &incidence) const override
+    Q_REQUIRED_RESULT QString displayName(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence)
         return QStringLiteral("Freebusy");
     }
 
-    QColor resourceColor(const KCalendarCore::Incidence::Ptr &incidence) const override
+    Q_REQUIRED_RESULT QColor resourceColor(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         bool ok = false;
         int status = incidence->customProperty(QStringLiteral("FREEBUSY").toLatin1(), QStringLiteral("STATUS").toLatin1()).toInt(&ok);
 
         if (!ok) {
-            return QColor(85, 85, 85);
+            return {85, 85, 85};
         }
 
         switch (status) {
         case KCalendarCore::FreeBusyPeriod::Busy:
-            return QColor(255, 0, 0);
+            return {255, 0, 0};
         case KCalendarCore::FreeBusyPeriod::BusyTentative:
         case KCalendarCore::FreeBusyPeriod::BusyUnavailable:
-            return QColor(255, 119, 0);
+            return {255, 119, 0};
         case KCalendarCore::FreeBusyPeriod::Free:
-            return QColor(0, 255, 0);
+            return {0, 255, 0};
         default:
-            return QColor(85, 85, 85);
+            return {85, 85, 85};
         }
     }
 
-    QString iconForIncidence(const KCalendarCore::Incidence::Ptr &incidence) const override
+    Q_REQUIRED_RESULT QString iconForIncidence(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence)
-        return QString();
+        return {};
     }
 
-    KCalendarCore::Calendar::Ptr getCalendar() const override
+    Q_REQUIRED_RESULT KCalendarCore::Calendar::Ptr getCalendar() const override
     {
         return mCalendar;
     }
@@ -153,17 +151,17 @@ ResourceManagement::~ResourceManagement()
 
 void ResourceManagement::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "ResourceManagement");
-    const QSize size = group.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myResourceManagementConfigGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void ResourceManagement::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "ResourceManagement");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), myResourceManagementConfigGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
 
